@@ -33,9 +33,10 @@
 #  define SYSTEMSETTINGSVIEW_DEPRECATED_NO_EXPORT SYSTEMSETTINGSVIEW_NO_EXPORT SYSTEMSETTINGSVIEW_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SYSTEMSETTINGSVIEW_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SYSTEMSETTINGSVIEW_NO_DEPRECATED
+#    define SYSTEMSETTINGSVIEW_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
